@@ -2,7 +2,7 @@
  * Copyright (c) 2006-2014 Erik Ekman <yarrick@kryo.se>,
  * 2006-2009 Bjorn Andersson <flex@kryo.se>
  *
- * Permission to use, copy, modify, and distribute this software for any
+ * Permission to use, copy, modify, and/or distribute this software for any
  * purpose with or without fee is hereby granted, provided that the above
  * copyright notice and this permission notice appear in all copies.
  *
@@ -22,7 +22,6 @@
 #include <errno.h>
 
 #include "encoding.h"
-#include "base32.h"
 #include "test.h"
 
 #define TUPLES 5
@@ -43,17 +42,14 @@ START_TEST(test_base32_encode)
 {
 	size_t len;
 	char buf[4096];
-	struct encoder *b32;
 	int val;
 
-	b32 = get_base32_encoder();
 
 	len = sizeof(buf);
-	val = b32->encode(buf, &len, testpairs[_i].a, strlen(testpairs[_i].a));
+	val = base32_ops.encode(buf, &len, testpairs[_i].a, strlen(testpairs[_i].a));
 
-	fail_unless(val == strlen(testpairs[_i].b));
-	fail_unless(strcmp(buf, testpairs[_i].b) == 0,
-			"'%s' != '%s'", buf, testpairs[_i].b);
+	ck_assert(val == strlen(testpairs[_i].b));
+	ck_assert_str_eq(buf, testpairs[_i].b);
 }
 END_TEST
 
@@ -61,17 +57,13 @@ START_TEST(test_base32_decode)
 {
 	size_t len;
 	char buf[4096];
-	struct encoder *b32;
 	int val;
 
-	b32 = get_base32_encoder();
-
 	len = sizeof(buf);
-	val = b32->decode(buf, &len, testpairs[_i].b, strlen(testpairs[_i].b));
+	val = base32_ops.decode(buf, &len, testpairs[_i].b, strlen(testpairs[_i].b));
 
-	fail_unless(val == strlen(testpairs[_i].a));
-	fail_unless(strcmp(buf, testpairs[_i].a) == 0,
-			"'%s' != '%s'", buf, testpairs[_i].a);
+	ck_assert(val == strlen(testpairs[_i].a));
+	ck_assert_str_eq(buf, testpairs[_i].a);
 }
 END_TEST
 
@@ -82,7 +74,7 @@ START_TEST(test_base32_5to8_8to5)
 
 	for (i = 0; i < 32; i++) {
 		c = b32_5to8(i);
-		fail_unless(b32_8to5(c) == i);
+		ck_assert(b32_8to5(c) == i);
 	}
 }
 END_TEST
@@ -93,14 +85,11 @@ START_TEST(test_base32_blksize)
 	size_t enclen;
 	char *rawbuf;
 	char *encbuf;
-	struct encoder *b32;
 	int i;
 	int val;
 
-	b32 = get_base32_encoder();
-
-	rawlen = b32->blocksize_raw();
-	enclen = b32->blocksize_encoded();
+	rawlen = base32_ops.blocksize_raw;
+	enclen = base32_ops.blocksize_encoded;
 
 	rawbuf = malloc(rawlen + 16);
 	encbuf = malloc(enclen + 16);
@@ -110,21 +99,21 @@ START_TEST(test_base32_blksize)
 	}
 	rawbuf[i] = 0;
 
-	val = b32->encode(encbuf, &enclen, rawbuf, rawlen);
+	val = base32_ops.encode(encbuf, &enclen, rawbuf, rawlen);
 
-	fail_unless(rawlen == 5, "raw length was %d not 5", rawlen);
-	fail_unless(enclen == 5, "encoded %d bytes, not 5", enclen);
-	fail_unless(val == 8, "encoded string %s was length %d", encbuf, val);
+	ck_assert_msg(rawlen == 5, "raw length was %zu not 5", rawlen);
+	ck_assert_msg(enclen == 5, "encoded %zu bytes, not 5", enclen);
+	ck_assert_msg(val == 8, "encoded string %s was length %d", encbuf, val);
 
 	memset(rawbuf, 0, rawlen + 16);
 
 	enclen = val;
-	val = b32->decode(rawbuf, &rawlen, encbuf, enclen);
+	val = base32_ops.decode(rawbuf, &rawlen, encbuf, enclen);
 
-	fail_unless(rawlen == 5, "raw length was %d not 5", rawlen);
-	fail_unless(val == 5, "val was not 5 but %d", val);
+	ck_assert_msg(rawlen == 5, "raw length was %zu not 5", rawlen);
+	ck_assert_msg(val == 5, "val was not 5 but %d", val);
 	for (i = 0; i < rawlen; i++) {
-		fail_unless(rawbuf[i] == 'A');
+		ck_assert(rawbuf[i] == 'A');
 	}
 }
 END_TEST
